app_tmp_path library

Functions

cleanAppTmpRootDir() Future<void>
Cleans app temporary root directory. It deletes all files and directories in the temporary directory.
cleanOSTmpDir() Future<void>
Cleans the OS root temporary directory. It deletes all files and directories in the temporary directory.
createAppTmpDir({String prefix = ''}) Future<String>
Creates a temporary directory in the app's root temporary directory.
createAppTmpFile({String prefix = '', String suffix = '', String? fileName}) Future<String>
Creates a temporary file path. The directory is created if it does not exist. If fileName is provided, the file will be created in a unique temporary directory. Otherwise, the file will be created directly in the app's root temporary directory.
getAppTmpRootDir() Future<String>
Returns app tmp root dir, which is <tmp_dir>/_app.
setAppTmpRootDir(String path) → void
Sets the app temporary root directory to a custom path. This is useful for testing purposes. The default app temporary root directory is <tmp_dir>/_app.
tmpFileName() String
Returns a temporary file name.