app_tmp_path
library
Functions
-
cleanAppRootTmpDir()
→ Future<void>
-
Cleans the app's root temporary directory. It deletes all files and directories in the temporary directory.
-
cleanAppTmpDir()
→ Future<void>
-
Cleans
<tmp_dir>/_app. It deletes all files and directories in the temporary directory.
-
createAppTmpPath({String prefix = ''})
→ Future<String>
-
Returns a temporary path in the
<tmp_dir>/_app. You can use that to create a temporary file or directory.
-
initAppTmpDir({bool? skipCreation})
→ Future<String>
-
Returns
<tmp_dir>/_app. If the directory does not exist, it will be created.
-
setAppTmpDir(String path)
→ void
-
Forces the
<tmp_dir>/_app to be set to a specific path. This is useful for testing purposes.
-
tmpFileName()
→ String
-
Returns a temporary file name.